==> ZenTaoPMS.17.5.php7.1.zip: zentaopms/module/projectrelease/lang/zh-cn.php <==
<?php
/**
 * The release module zh-cn file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2020 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yuchun Li <liyuchun@cnezsoft.com>
 * @package     release
 * @version     $Id: zh-cn.php 4129 2020-11-27 01:58:14Z wwccss $
 * @link        http://www.zentao.net
 */
$lang->projectrelease->common           = '项目发布';
$lang->projectrelease->create           = "创建发布";
$lang->projectrelease->edit             = "编辑发布";
$lang->projectrelease->linkStory        = "关联{$lang->SRCommon}";
$lang->projectrelease->linkBug          = "关联Bug";
$lang->projectrelease->delete           = "删除发布";
$lang->projectrelease->deleted          = '已删除';
$lang->projectrelease->view             = "发布详情";
$lang->projectrelease->browse           = "浏览发布";
$lang->projectrelease->changeStatus     = "修改状态";
$lang->projectrelease->batchUnlink      = "批量移除";
$lang->projectrelease->batchUnlinkStory = "批量移除{$lang->SRCommon}";
$lang->projectrelease->batchUnlinkBug   = "批量移除Bug";
$lang->projectrelease->unlinkStory      = "移除{$lang->SRCommon}";
$lang->projectrelease->unlinkBug        = '移除Bug';
$lang->projectrelease->export           = '导出HTML';
$lang->projectrelease->browseAction     = "发布列表";
$lang->projectrelease->notify           = "通知";

$lang->projectrelease->featureBar['browse']['all']       = '全部';
$lang->projectrelease->featureBar['browse']['normal']    = '正常';
$lang->projectrelease->featureBar['browse']['terminate'] = '停止维护';

==> ZenTaoPMS-20.0-php7.2_7.4.zip: zentaopms/module/projectrelease/lang/zh-cn.php <==
<?php
/**
 * The release module zh-cn file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2023 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.cnezsoft.com)
 * @license     ZPL(http://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yuchun Li <liyuchun@cnezsoft.com>
 * @package     release
 * @version     $Id: zh-cn.php 4129 2020-11-27 01:58:14Z wwccss $
 * @link        https://www.zentao.net
 */
$lang->projectrelease->common           = $lang->projectCommon . '发布';
$lang->projectrelease->create           = "创建发布";
$lang->projectrelease->edit             = "编辑发布";
$lang->projectrelease->linkStory        = "关联{$lang->SRCommon}";
$lang->projectrelease->linkBug          = "关联Bug";
$lang->projectrelease->delete           = "删除发布";
$lang->projectrelease->deleted          = '已删除';
$lang->projectrelease->view             = "发布详情";
$lang->projectrelease->browse           = "浏览发布";
$lang->projectrelease->changeStatus     = "修改状态";
$lang->projectrelease->batchUnlink      = "批量移除";
$lang->projectrelease->batchUnlinkStory = "批量移除{$lang->SRCommon}";
$lang->projectrelease->batchUnlinkBug   = "批量移除Bug";
$lang->projectrelease->unlinkStory      = "移除{$lang->SRCommon}";
$lang->projectrelease->unlinkBug        = '移除Bug';
$lang->projectrelease->export           = '导出HTML';
$lang->projectrelease->browseAction     = "发布列表";
$lang->projectrelease->notify           = "通知";
$lang->projectrelease->product          = "所属{$lang->productCommon}";
$lang->projectrelease->name             = "发布名称";

$lang->projectrelease->featureBar['browse']['all']       = '全部';
$lang->projectrelease->featureBar['browse']['normal']    = '正常';
$lang->projectrelease->featureBar['browse']['terminate'] = '停止维护';
